==> hoc-1.32.0.tgz: package/lib/withIntersectionObserver.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { jsx as _jsx } from "react/jsx-runtime";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";

/* global IntersectionObserver */
import React, { Component } from 'react';

var shouldLoadIntersectionObserver = function shouldLoadIntersectionObserver() {
  return !('IntersectionObserver' in window) || !('IntersectionObserverEntry' in window) || !('intersectionRatio' in window.IntersectionObserverEntry.prototype);
};

export var hocIntersectionObserverWithOptions = function hocIntersectionObserverWithOptions(options) {
  if (options === void 0) {
    options = {};
  }

  return function (BaseComponent) {
    var _class, _temp;

    var displayName = BaseComponent.displayName;
    return _temp = _class = /*#__PURE__*/function (_Component) {
      _inheritsLoose(WithIntersectionObserver, _Component);

      function WithIntersectionObserver() {
        var _this;

        for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
          args[_key] = arguments[_key];
        }

        _this = _Component.call.apply(_Component, [this].concat(args)) || this;
        _this.state = {
          isIntersecting: true,
          intersectionObserver: null
        };

        _this.handleChange = function (_ref) {
          var isIntersecting = _ref[0].isIntersecting;

          _this.setState({
            isIntersecting: isIntersecting
          });
        };

        _this.innerRef = function (elem) {
          _this.refTarget = elem;
        };

        return _this;
      }

      var _proto = WithIntersectionObserver.prototype;

      _proto.componentDidMount = /*#__PURE__*/function () {
        var _componentDidMount = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
          var _this2 = this;

          var target;
          return _regeneratorRuntime.wrap(function _callee$(_context) {
            while (1) {
              switch (_context.prev = _context.next) {
                case 0:
                  target = this.refTarget;

                  if (!shouldLoadIntersectionObserver()) {
                    _context.next = 4;
                    break;
                  }

                  _context.next = 4;
                  return import(
                  /* webpackChunkName: "intersection-observer" */
                  'intersection-observer');

                case 4:
                  this.setState({
                    intersectionObserver: new IntersectionObserver(this.handleChange)
                  }, function () {
                    return _this2.state.intersectionObserver.observe(target, options);
                  });

                case 5:
                case "end":
                  return _context.stop();
              }
            }
          }, _callee, this);
        }));

        function componentDidMount() {
          return _componentDidMount.apply(this, arguments);
        }

        return componentDidMount;
      }();

      _proto.componentWillUnmount = function componentWillUnmount() {
        if (this.state.intersectionObserver) {
          this.state.intersectionObserver.disconnect();
        }
      };

      _proto.render = function render() {
        var isVisible = this.state.isIntersecting;
        return /*#__PURE__*/_jsx(BaseComponent, _extends({}, this.props, {
          isVisible: isVisible,
          innerRef: this.innerRef
        }));
      };

      return WithIntersectionObserver;
    }(Component), _class.displayName = "withIntersectionObserver(" + displayName + ")", _class.contextTypes = BaseComponent.contextTypes, _temp;
  };
};
export default hocIntersectionObserverWithOptions();

==> hoc-1.33.0.tgz: package/lib/withIntersectionObserver.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";

/* global IntersectionObserver */
import React, { Component } from 'react';
import { jsx as _jsx } from "react/jsx-runtime";

var shouldLoadIntersectionObserver = function shouldLoadIntersectionObserver() {
  return !('IntersectionObserver' in window) || !('IntersectionObserverEntry' in window) || !('intersectionRatio' in window.IntersectionObserverEntry.prototype) || !('isIntersecting' in window.IntersectionObserverEntry.prototype);
};

export var hocIntersectionObserverWithOptions = function hocIntersectionObserverWithOptions(options) {
  if (options === void 0) {
    options = {};
  }

  return function (BaseComponent) {
    var _class, _temp;

    var displayName = BaseComponent.displayName;
    return _temp = _class = /*#__PURE__*/function (_Component) {
      _inheritsLoose(WithIntersectionObserver, _Component);

      function WithIntersectionObserver() {
        var _this;

        for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
          args[_key] = arguments[_key];
        }

        _this = _Component.call.apply(_Component, [this].concat(args)) || this;
        _this.state = {
          isIntersecting: true,
          intersectionObserver: null
        };

        _this.handleChange = function (_ref) {
          var isIntersecting = _ref[0].isIntersecting;

          _this.setState({
            isIntersecting: isIntersecting
          });
        };

        _this.innerRef = function (elem) {
          _this.refTarget = elem;
        };

        return _this;
      }

      var _proto = WithIntersectionObserver.prototype;

      _proto.componentDidMount = /*#__PURE__*/function () {
        var _componentDidMount = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
          var _this2 = this;

          var target;
          return _regeneratorRuntime.wrap(function _callee$(_context) {
            while (1) {
              switch (_context.prev = _context.next) {
                case 0:
                  target = this.refTarget;

                  if (!shouldLoadIntersectionObserver()) {
                    _context.next = 4;
                    break;
                  }

                  _context.next = 4;
                  return import(
                  /* webpackChunkName: "intersection-observer" */
                  'intersection-observer');

                case 4:
                  this.setState({
                    intersectionObserver: new IntersectionObserver(this.handleChange)
                  }, function () {
                    return _this2.state.intersectionObserver.observe(target, options);
                  });

                case 5:
                case "end":
                  return _context.stop();
              }
            }
          }, _callee, this);
        }));

        function componentDidMount() {
          return _componentDidMount.apply(this, arguments);
        }

        return componentDidMount;
      }();

      _proto.componentWillUnmount = function componentWillUnmount() {
        if (this.state.intersectionObserver) {
          this.state.intersectionObserver.disconnect();
        }
      };

      _proto.render = function render() {
        var isVisible = this.state.isIntersecting;
        return /*#__PURE__*/_jsx(BaseComponent, _extends({}, this.props, {
          isVisible: isVisible,
          innerRef: this.innerRef
        }));
      };

      return WithIntersectionObserver;
    }(Component), _class.displayName = "withIntersectionObserver(" + displayName + ")", _class.contextTypes = BaseComponent.contextTypes, _temp;
  };
};
export default hocIntersectionObserverWithOptions();
